@@ -14,6 +14,8 @@ from datetime import datetime
 import locale
 import sys
 import xmlrpclib
+from os import path, environ
+from json import load
 
 locale.setlocale(locale.LC_ALL, '')
 
@@ -170,20 +172,39 @@ Possible matches include:
 """ % params
     ### gruiky to override coupling
         self.save()
+"""sur recommandation de grenoya :)"""
+import argparse
+parser = argparse.ArgumentParser(description = '''
+    Gathers download stats from pypi regarding the download information of the geiven package.
+    Print them, and stores them in a file for further use. If no package name are provided, it will try to get all packages known from previously fetched stats.''')
 
-from optparse import OptionParser
-parser = OptionParser()
+parser.add_argument('_package', metavar='package_name' , type = str,
+    nargs='?', help='package name to be retrieved')
 
-parser.add_option("-p",'--package', dest="_package", 
-    help='packages for wich to retrieve the stat',
-    action='append'
-)
+options = parser.parse_args()
 
-(options, args) = parser.parse_args()
+guessed = set()
+saved=path.join(environ["HOME"], ".pipy.stat.json"  )
+try:
+    with open(saved  ) as f:
+        guessed =  reduce( 
+            set.union, 
+                map( 
+                    lambda x : set( [  x['name'] ]  ), load(f)
+                )
+            )
+        print  "found %s" % ",".join(guessed)
+except:
+    print "could not load previously stored stats to guess packages"
 
-
-for pkg in options._package:
-    PyPIDownloadAggregator(pkg).stats()
+for pkg in options._package or guessed :
+    from time import sleep
+    try:
+        sleep(1)
+        gni = PyPIDownloadAggregator(str(pkg))
+        gni.stats()
+    except:
+        print "fetching stats for *%s* failed" % pkg 
 
 
    
